
# bwa mem + sort
echo TimeStamp 01: bwa_mem+sort
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/bwa-0.7.13/bwa mem -t 60 -M -Y \
    -R "@RG\tID:PE100\tPL:COMPLETE\tPU:PE100\tLB:NA12878\tSM:PE100\tCN:NIST" \
    ./hs37d5/hs37d5.fa \
    ./read_1.fq.gz.clean.gz ./read_2.fq.gz.clean.gz \
  | ./BIN/samtools-1.3/bin/samtools view -buhS \
    -t ./hs37d5/hs37d5.fa.fai - \
  | ./BIN/samtools-1.3/bin/samtools sort -m 1000000000 \
  -T ./PE100.sort \
  -o ./PE100.1.sorted.bam -
End=`date +%s`
Dif=$[End - Start]
echo TIME bwa_mem+sort $Dif s

# mark dup
echo TimeStamp 02: picard_MarkDuplicates
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/jdk1.8.0_131/bin/java -jar ./BIN/picard.jar MarkDuplicates \
    I=./PE100.1.sorted.bam \
    O=./PE100.2.rmdup.bam \
    M=./PE100.2.rmdup.mat \
    REMOVE_DUPLICATES=false \
    TMP_DIR=./tmp
End=`date +%s`
Dif=$[End - Start]
echo TIME picard_MarkDuplicates $Dif s

# index alignment
echo TimeStamp 03: samtools_index[rmdup.bam]
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/samtools-1.3/bin/samtools index \
    ./PE100.2.rmdup.bam
End=`date +%s`
Dif=$[End - Start]
echo TIME samtools_index[rmdup.bam] $Dif s

# BQSR
echo TimeStamp 06: GATK_BaseRecalibrator
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/jdk1.8.0_131/bin/java -jar ./GATK_stat/lib/GenomeAnalysisTK.3.7-0/GenomeAnalysisTK.jar \
    --disable_auto_index_creation_and_locking_when_reading_rods \
    -T BaseRecalibrator \
    -nct 40 \
    -R ./hs37d5/hs37d5.fa \
    -I ./PE100.2.rmdup.bam \
    -o ./PE100.4.bqsr.grp \
    -knownSites ./hs37d5/Mills_and_1000G_gold_standard.indels.b37.vcf.gz \
    -knownSites ./hs37d5/1000G_phase1.indels.b37.vcf.gz \
    -knownSites ./hs37d5/dbsnp_138.b37.vcf.gz
End=`date +%s`
Dif=$[End - Start]
echo TIME GATK_BaseRecalibrator $Dif s

echo TimeStamp 07: GATK_PrintReads
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/jdk1.8.0_131/bin/java -jar ./GATK_stat/lib/GenomeAnalysisTK.3.7-0/GenomeAnalysisTK.jar \
    --disable_auto_index_creation_and_locking_when_reading_rods \
    -T PrintReads \
    -nct 7 \
    -R ./hs37d5/hs37d5.fa \
    -I ./PE100.2.rmdup.bam \
    -BQSR ./PE100.4.bqsr.grp \
    -o ./PE100.4.bqsr.bam \
    -baqGOP 30
End=`date +%s`
Dif=$[End - Start]
echo TIME GATK_PrintReads $Dif s

# index alignment
echo TimeStamp 08: samtools_index[bqsr.bam]
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/samtools-1.3/bin/samtools index \
    ./PE100.4.bqsr.bam
End=`date +%s`
Dif=$[End - Start]
echo TIME samtools_index[bqsr.bam] $Dif s

