# bwa mem + sort
echo TimeStamp 01: bwa_mem+sort
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/bwa-0.7.13/bwa mem -t 60 -M -Y \
    -R "@RG\tID:normal-wes\tPL:COMPLETE\tPU:normal-wes\tLB:NA12878\tSM:normal-wes\tCN:NIST" \
    ./reference/hg19.fa \
    ./n_read_1.fq.gz ./n_read_2.fq.gz \
  | ./BIN/samtools-1.3/bin/samtools view -buhS \
    -t ./reference/hg19.fa.fai - \
  | ./BIN/samtools-1.3/bin/samtools sort -m 1000000000 \
  -T ./normal-wes.sort \
  -o ./normal-wes.1.sorted.bam -
End=`date +%s`
Dif=$[End - Start]
echo TIME bwa_mem+sort $Dif s

# mark dup
echo TimeStamp 02: picard_MarkDuplicates
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/jdk1.8.0_131/bin/java -jar ./BIN/picard.jar MarkDuplicates \
    I=./normal-wes.1.sorted.bam \
    O=./normal-wes.sortdup.bam \
    M=./normal-wes.sortdup.mat \
    REMOVE_DUPLICATES=false \
    TMP_DIR=./tmp
End=`date +%s`
Dif=$[End - Start]
echo TIME picard_MarkDuplicates $Dif s

# index alignment
echo TimeStamp 03: samtools_index[rmdup.bam]
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/samtools-1.3/bin/samtools index \
    ./normal-wes.sortdup.bam
End=`date +%s`
Dif=$[End - Start]
echo TIME samtools_index[rmdup.bam] $Dif s

# BQSR
echo TimeStamp 06: GATK_BaseRecalibrator
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/jdk1.8.0_131/bin/java -jar ./GATK_stat/lib/GenomeAnalysisTK.3.7-0/GenomeAnalysisTK.jar \
    --disable_auto_index_creation_and_locking_when_reading_rods \
    -T BaseRecalibrator \
    -nct 40 \
    -R ./reference/hg19.fa \
    -I ./normal-wes.sortdup.bam \
    -o ./normal-wes.sortdup.bqsr.grp \
    -knownSites ./reference/Mills_and_1000G_gold_standard.indels.hg19.vcf.gz \
    -knownSites ./reference/1000G_phase1.indels.hg19.vcf.gz \
    -knownSites ./reference/dbsnp_151.vcf.gz
End=`date +%s`
Dif=$[End - Start]
echo TIME GATK_BaseRecalibrator $Dif s

echo TimeStamp 07: GATK_PrintReads
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/jdk1.8.0_131/bin/java -jar ./GATK_stat/lib/GenomeAnalysisTK.3.7-0/GenomeAnalysisTK.jar \
    --disable_auto_index_creation_and_locking_when_reading_rods \
    -T PrintReads \
    -nct 7 \
    -R ./reference/hg19.fa \
    -I ./normal-wes.sortdup.bam \
    -BQSR ./normal-wes.sortdup.bqsr.grp \
    -o ./normal-wes.sortdup.bqsr.bam \
    -baqGOP 30
End=`date +%s`
Dif=$[End - Start]
echo TIME GATK_PrintReads $Dif s

# index alignment
echo TimeStamp 08: samtools_index[bqsr.bam]
date "+%Y-%m-%d %H:%M:%S"
Start=`date +%s`
  ./BIN/samtools-1.3/bin/samtools index \
    ./normal-wes.sortdup.bqsr.bam
End=`date +%s`
Dif=$[End - Start]
echo TIME samtools_index[bqsr.bam] $Dif s

